@@ -11,7 +11,7 @@ from enum import Enum
 List  = typing.List
 Tuple = typing.Tuple
 pypi_base_url = "http://zifuture.com:1556/fs/pypi"
-version = "1.1.16"
+version = "1.1.18"
 
 lean_metas = [
     {
@@ -386,14 +386,6 @@ def get_python_link_name(pydll_path, os_name):
     return None, None
 
 os_name = platform.system().lower()
-current_kernel_module_driver_version = get_current_driver_version()
-assert current_kernel_module_driver_version is not None, "Can not fetch kernel module driver version"
-
-lean_meta = list(filter(lambda x:compare_version_a_lesseq_b(x[f"min_driver_version_{os_name}"], current_kernel_module_driver_version), lean_metas))
-all_min_driver_versions = [x[f"min_driver_version_{os_name}"] for x in lean_metas]
-all_min_driver_versions_str = ", ".join(all_min_driver_versions)
-assert len(lean_meta) > 0, f"Unsupport kernel module driver version {current_kernel_module_driver_version}, please update your graphics driver to greater than {all_min_driver_versions_str}"
-
 python_version = python_version_lite()
 python_version_module_name = "py" + python_version.replace(".", "")
 trtpy_root = os.path.realpath(os.path.dirname(os.path.abspath(__file__)))
@@ -403,12 +395,6 @@ pydll_path = os.path.join(sys.exec_prefix, "lib")
 pydll_link_name, pydll_full_path = get_python_link_name(pydll_path, os_name)
 inited = False
 
-supported_pycs = []
-for meta in lean_meta:
-    supported_pycs.extend(filter(lambda x:x["python"] == python_version, meta["pycs"]))
-
-assert len(supported_pycs) > 0, f"Unsupported platform [python {python_version}], Could'nt found pyc_meta."
-
 module_variables = locals()
 def update_module_variables(module_variables, module):
     for k in dir(module):
@@ -464,7 +450,6 @@ def set_exec_permission(directory):
 def __load_symbols(pyc_meta, load_lean_library=True):
 
     global module_variables, loaded_module, inited
-
     select_nvbinary_version = pyc_meta["lean"]
     binary_url_prefix = pyc_meta["binary_url_prefix"]
     lean_meta = list(filter(lambda x:x["name"] == select_nvbinary_version, lean_metas))[0]
@@ -720,6 +705,25 @@ def init(cuda_version : str=None, tensorrt_version : str=None, load_lean_library
     if inited:
         return
 
+    global module_variables
+    current_kernel_module_driver_version = get_current_driver_version()
+    assert current_kernel_module_driver_version is not None, "Can not fetch kernel module driver version"
+
+    lean_meta = list(filter(lambda x:compare_version_a_lesseq_b(x[f"min_driver_version_{os_name}"], current_kernel_module_driver_version), lean_metas))
+    all_min_driver_versions = [x[f"min_driver_version_{os_name}"] for x in lean_metas]
+    all_min_driver_versions_str = ", ".join(all_min_driver_versions)
+    assert len(lean_meta) > 0, f"Unsupport kernel module driver version {current_kernel_module_driver_version}, please update your graphics driver to greater than {all_min_driver_versions_str}"
+
+    supported_pycs = []
+    for meta in lean_meta:
+        supported_pycs.extend(filter(lambda x:x["python"] == python_version, meta["pycs"]))
+
+    assert len(supported_pycs) > 0, f"Unsupported platform [python {python_version}], Could'nt found pyc_meta."
+    module_variables["current_kernel_module_driver_version"] = current_kernel_module_driver_version
+    module_variables["all_min_driver_versions"] = all_min_driver_versions
+    module_variables["lean_meta"] = lean_meta
+    module_variables["supported_pycs"] = supported_pycs
+
     if cuda_version is None and tensorrt_version is None:
         already_download_nvbinarys = get_already_download_nvbinary()
         if len(already_download_nvbinarys) > 0:
