@@ -29,17 +29,18 @@ def do_get_env(args):
     return 0
 
 def do_info(args):
-    if args.cuda is not None or args.trt is not None:
-        trtpy.init(cuda_version=args.cuda, tensorrt_version=args.trt)
+    if args.init or args.cuda is not None or args.trt is not None:
+        trtpy.init(cuda_version=args.cuda, tensorrt_version=args.trt, load_lean_library=args.tryload)
 
     print("Variables: ")
     for key, value in get_variable_template():
         print(f"  {key} = {value}")
 
-    print(f"Current kernel module driver version: {trtpy.current_kernel_module_driver_version}")
-    print(f"Support list: {len(trtpy.supported_pycs)} elements")
-    for i, pyc in enumerate(trtpy.supported_pycs):
-        trtpy.print_pyc(pyc, i)
+    if trtpy.inited:
+        print(f"Current kernel module driver version: {trtpy.current_kernel_module_driver_version}")
+        print(f"Support list: {len(trtpy.supported_pycs)} elements")
+        for i, pyc in enumerate(trtpy.supported_pycs):
+            trtpy.print_pyc(pyc, i)
     return 0
 
 def do_local_cpp_pkg(args):
@@ -193,7 +194,7 @@ def do_get_templ(args):
 
     if not args.raw:
         trtpy.init(cuda_version=args.cuda, tensorrt_version=args.trt, load_lean_library=False)
-        
+
     url = f"{trtpy.pypi_base_url}/code_template/{args.template}.zip"
     cache_zip = os.path.join(downloader.CACHE_ROOT, "code_template", f"{args.template}.zip")
     if not args.download and os.path.exists(cache_zip):
@@ -223,7 +224,7 @@ def remove_tree_keep_father(path):
         else:
             os.remove(full_path)
 
-def extract_series_templ(meta, saveto, raw, download):
+def extract_series_templ(meta, saveto, raw, download, cuda, trt):
 
     series_name = meta["name"]
     current_index = meta["current-index"]
@@ -252,6 +253,7 @@ def extract_series_templ(meta, saveto, raw, download):
 
     if not raw:
         print("Replace project variable")
+        trtpy.init(cuda_version=cuda, tensorrt_version=trt, load_lean_library=False)
         variable_template = get_variable_template()
         process_code_template.process_code_template(saveto, namelist, variable_template)
 
@@ -284,7 +286,6 @@ def do_get_series(args):
         print(f"{args.saveto} is file")
         return 1
 
-    trtpy.init(cuda_version=args.cuda, tensorrt_version=args.trt, load_lean_library=False)
     meta_url = f"{trtpy.pypi_base_url}/code_template/{args.name}.series.json"
     meta_cache_local_file = os.path.join(downloader.CACHE_ROOT, "code_template", f"{args.name}.series.json")
     if not args.download and os.path.exists(meta_cache_local_file):
@@ -302,7 +303,7 @@ def do_get_series(args):
         print(f"Series list-templ is empty")
         return 0
 
-    return extract_series_templ(meta, args.saveto, args.raw, args.download)
+    return extract_series_templ(meta, args.saveto, args.raw, args.download, args.cuda, args.trt)
 
 
 def do_change_proj(args):
@@ -313,7 +314,6 @@ def do_change_proj(args):
         print(f"Current is not series folder")
         return 1
 
-    trtpy.init(cuda_version=args.cuda, tensorrt_version=args.trt, load_lean_library=False)
     meta = json.load(open(config_json_file, "r"))
     current_index = meta["current-index"]
     templ_list = meta["list-templ"]
@@ -347,7 +347,7 @@ def do_change_proj(args):
         for index, names, templ_descript in index_names_map:
             if args.index in names:
                 meta["current-index"] = index
-                return extract_series_templ(meta, current_dir, args.raw, args.download)
+                return extract_series_templ(meta, current_dir, args.raw, args.download, args.cuda, args.trt)
     
     print(f"List templ: ")
     for index, names, templ_descript in index_names_map:
@@ -614,7 +614,9 @@ if __name__ == "__main__":
     parser = argparse.ArgumentParser()
     subp = parser.add_subparsers(dest="cmd")
     new_parser_with_version("get-env", help="download environment")
-    new_parser_with_version("info", help="display support list")
+    p = new_parser_with_version("info", help="display support list")
+    p.add_argument("--init", action="store_true", help="init after display")
+    p.add_argument("--tryload", action="store_true", help="try to load dynamic library")
     new_parser_with_version("mnist-test", help="test tensorrt with mnist")
     
     p = new_parser_with_version("exec", help="same to ./trtexec")
